@@ -6,24 +6,12 @@
  *                                <zeeshanak@gnome.org>
  *          Jorn Baayen <jorn@openedhand.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_PROTOCOL_INFO_H__
-#define __GUPNP_PROTOCOL_INFO_H__
+#ifndef GUPNP_PROTOCOL_INFO_H
+#define GUPNP_PROTOCOL_INFO_H
 
 #include <stdarg.h>
 #include <glib-object.h>
@@ -32,39 +20,15 @@
 
 G_BEGIN_DECLS
 
-GType
-gupnp_protocol_info_get_type (void) G_GNUC_CONST;
+G_DECLARE_DERIVABLE_TYPE (GUPnPProtocolInfo,
+                          gupnp_protocol_info,
+                          GUPNP,
+                          PROTOCOL_INFO,
+                          GObject)
 
-#define GUPNP_TYPE_PROTOCOL_INFO \
-                (gupnp_protocol_info_get_type ())
-#define GUPNP_PROTOCOL_INFO(obj) \
-                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                 GUPNP_TYPE_PROTOCOL_INFO, \
-                 GUPnPProtocolInfo))
-#define GUPNP_PROTOCOL_INFO_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_CAST ((obj), \
-                 GUPNP_TYPE_PROTOCOL_INFO, \
-                 GUPnPProtocolInfoClass))
-#define GUPNP_IS_PROTOCOL_INFO(obj) \
-                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                 GUPNP_TYPE_PROTOCOL_INFO))
-#define GUPNP_IS_PROTOCOL_INFO_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_TYPE ((obj), \
-                 GUPNP_TYPE_PROTOCOL_INFO))
-#define GUPNP_PROTOCOL_INFO_GET_CLASS(obj) \
-                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-                 GUPNP_TYPE_PROTOCOL_INFO, \
-                 GUPnPProtocolInfoClass))
+#define GUPNP_TYPE_PROTOCOL_INFO (gupnp_protocol_info_get_type ())
 
-typedef struct _GUPnPProtocolInfoPrivate GUPnPProtocolInfoPrivate;
-
-typedef struct {
-        GObject parent;
-
-        GUPnPProtocolInfoPrivate *priv;
-} GUPnPProtocolInfo;
-
-typedef struct {
+struct _GUPnPProtocolInfoClass {
         GObjectClass parent_class;
 
         /* future padding */
@@ -72,7 +36,7 @@ typedef struct {
         void (* _gupnp_reserved2) (void);
         void (* _gupnp_reserved3) (void);
         void (* _gupnp_reserved4) (void);
-} GUPnPProtocolInfoClass;
+};
 
 GUPnPProtocolInfo *
 gupnp_protocol_info_new                 (void);
@@ -146,4 +110,4 @@ gupnp_protocol_info_get_dlna_flags      (GUPnPProtocolInfo *info);
 
 G_END_DECLS
 
-#endif /* __GUPNP_PROTOCOL_INFO_H__ */
+#endif /* GUPNP_PROTOCOL_INFO_H */
